Enum precis_core::context::ContextRuleError[][src]

pub enum ContextRuleError {
    NotApplicable,
    Undefined,
}
Error associated to the application of any context rule.

Variants

NotApplicable

Context rule is not applicable

Undefined

Special value used to deal with any error conditions, such as an attempt to test a character before the start of a label or after the end of a label.