Enum precis_core::DerivedPropertyValue [−][src]
pub enum DerivedPropertyValue {
PValid,
SpecClassPval,
SpecClassDis,
ContextJ,
ContextO,
Disallowed,
Unassigned,
}Expand description
Derived property value
Notes
- SpecClassPVal maps to those code points that are allowed
to be used in specific string classes such as
IdentifierClassandFreeformClass. PRECIS framework defines two allowed values for above classes (ID_PVAL adn FREE_PVAL). In practice, the derived property ID_PVAL is not used in this specification, because every ID_PVAL code point is PVALID, so only FREE_PVAL is actually mapped to SpecClassPVal. - SpecClassDis maps to those code points that are not to be
included in one of the string classes but that might be permitted
in others. PRECIS framework defines “FREE_DIS” for the
FreeformClassand “ID_DIS” for theIdentifierClass. In practice, the derived property FREE_DIS is not used in this specification, because every FREE_DIS code point is DISALLOWED, so only ID_DIS is mapped to SpecClassDis. Both SpecClassPVal and SpecClassDis values are used to ease extension if more classes are added beyondIdentifierClassandFreeformClassin the future.
Variants
PValid
Value assigned to all those code points that are allowed to be used in any PRECIS string class.
SpecClassPval
Value assigned to all those code points that are allowed to be used in an specific PRECIS string class.
SpecClassDis
Value assigned to all those code points that are disallowed by a specific PRECIS string class.
ContextJ
Contextual rule required for Join_controls Unicode codepoints.
ContextO
Contextual rule required for Others Unicode codepoints.
Disallowed
Those code points that are not permitted in any PRECIS string class.
Unassigned
Those code points that are not designated in the Unicode Standard.