Enum precis_core::UnexpectedError
source · [−]pub enum UnexpectedError {
ContextRuleNotApplicable(CodepointInfo),
MissingContextRule(CodepointInfo),
ProfileRuleNotApplicable,
Undefined,
}Expand description
Internal errors that group unusual error conditions that mostly have to do with the processing of wrong labels, unexpected Unicode code points if tested against another version defined in PRECIS, etc.
Variants
ContextRuleNotApplicable(CodepointInfo)
Error caused when trying to apply a context rule over an invalid code point.
MissingContextRule(CodepointInfo)
The code point requires a context rule that is not implemented.
CodepointInfo contains information about the code point.
ProfileRuleNotApplicable
Error caused when trying to apply a context rule that is not defined by the PRECIS profile.
Undefined
Unexpected error condition such as an attempt to access to a character before the start of a label or after the end of a label.