Enum precis_core::error::Error [−][src]
pub enum Error {
Disallowed,
NotApplicable,
Undefined,
Unexpected,
}Expand description
Represents any kind of error that can occur while parsing files
pub enum Error {
Disallowed,
NotApplicable,
Undefined,
Unexpected,
}Represents any kind of error that can occur while parsing files