Module precis_core::stringclasses[][src]

Structs

Concrete class representing PRECIS FreeformClass from RFC 8264.

Concrete class representing PRECIS IdentifierClass from RFC 8264.

Traits

Interface for specific classes to deal with specific unicode code groups defined in RFC 8264. Next callbacks will be invoked to calculate the derived property value in the order defined in get_derived_property_value

Base interface for all String classes in PRECIS framework.

Functions

Implements the algorithm to calculate the value of the derived property. This algorithm is as follows (implementations MUST NOT modify the order of operations within this algorithm, because doing so would cause inconsistent results across implementations):