Struct precis_core::stringclasses::FreeformClass
source · [−]pub struct FreeformClass {}Expand description
Concrete class representing PRECIS FreeformClass from
RFC 8264.
Example
let ff = FreeformClass {};
// character 𐍁 is OtherLetterDigits (R)
assert_eq!(ff.get_value_from_char('𐍁'), DerivedPropertyValue::SpecClassPval);
// Character S is ASCII7 (K)
assert_eq!(ff.get_value_from_char('S'), DerivedPropertyValue::PValid);
// Character 0x1170 is OldHangulJamo (I)
assert_eq!(ff.get_value_from_codepoint(0x1170), DerivedPropertyValue::Disallowed);Trait Implementations
sourceimpl SpecificDerivedPropertyValue for FreeformClass
impl SpecificDerivedPropertyValue for FreeformClass
sourcefn on_has_compat(&self) -> DerivedPropertyValue
fn on_has_compat(&self) -> DerivedPropertyValue
sourcefn on_other_letter_digits(&self) -> DerivedPropertyValue
fn on_other_letter_digits(&self) -> DerivedPropertyValue
Callback invoked when the Unicode code point belongs to
OtherLetterDigits Read more
sourcefn on_spaces(&self) -> DerivedPropertyValue
fn on_spaces(&self) -> DerivedPropertyValue
sourcefn on_symbols(&self) -> DerivedPropertyValue
fn on_symbols(&self) -> DerivedPropertyValue
sourcefn on_punctuation(&self) -> DerivedPropertyValue
fn on_punctuation(&self) -> DerivedPropertyValue
Callback invoked when the Unicode code point belongs to Punctuation Read more
sourceimpl StringClass for FreeformClass
impl StringClass for FreeformClass
sourcefn get_value_from_char(&self, c: char) -> DerivedPropertyValue
fn get_value_from_char(&self, c: char) -> DerivedPropertyValue
sourcefn get_value_from_codepoint(&self, cp: u32) -> DerivedPropertyValue
fn get_value_from_codepoint(&self, cp: u32) -> DerivedPropertyValue