Struct precis_core::stringclasses::IdentifierClass
source · [−]pub struct IdentifierClass {}Expand description
Concrete class representing PRECIS IdentifierClass from
RFC 8264.
Example
let id = IdentifierClass {};
// character 𐍁 is OtherLetterDigits (R)
assert_eq!(id.get_value_from_char('𐍁'), DerivedPropertyValue::SpecClassDis);
// Character S is ASCII7 (K)
assert_eq!(id.get_value_from_char('S'), DerivedPropertyValue::PValid);
// Character 0x1170 is OldHangulJamo (I)
assert_eq!(id.get_value_from_codepoint(0x1170), DerivedPropertyValue::Disallowed);Trait Implementations
sourceimpl SpecificDerivedPropertyValue for IdentifierClass
impl SpecificDerivedPropertyValue for IdentifierClass
sourcefn on_has_compat(&self) -> DerivedPropertyValue
fn on_has_compat(&self) -> DerivedPropertyValue
sourcefn on_other_letter_digits(&self) -> DerivedPropertyValue
fn on_other_letter_digits(&self) -> DerivedPropertyValue
Callback invoked when the Unicode code point belongs to
OtherLetterDigits Read more
sourcefn on_spaces(&self) -> DerivedPropertyValue
fn on_spaces(&self) -> DerivedPropertyValue
sourcefn on_symbols(&self) -> DerivedPropertyValue
fn on_symbols(&self) -> DerivedPropertyValue
sourcefn on_punctuation(&self) -> DerivedPropertyValue
fn on_punctuation(&self) -> DerivedPropertyValue
Callback invoked when the Unicode code point belongs to Punctuation Read more
sourceimpl StringClass for IdentifierClass
impl StringClass for IdentifierClass
sourcefn get_value_from_char(&self, c: char) -> DerivedPropertyValue
fn get_value_from_char(&self, c: char) -> DerivedPropertyValue
sourcefn get_value_from_codepoint(&self, cp: u32) -> DerivedPropertyValue
fn get_value_from_codepoint(&self, cp: u32) -> DerivedPropertyValue