pub struct CodepointInfo {
    pub cp: u32,
    pub position: usize,
    pub property: DerivedPropertyValue,
}
Error that contains information regarding the wrong Unicode code point

Fields

cp: u32

Unicode code point

position: usize

The position of the Unicode code point in the label

property: DerivedPropertyValue

The derived property value

Implementations

Creates a new CodepointInfo struct