Enum precis_core::Error
source · [−]pub enum Error {
Invalid,
BadCodepoint(CodepointInfo),
Unexpected(UnexpectedError),
}Expand description
Represents any kind of error that may happen when preparing, enforcing or comparing internationalized strings
Variants
Invalid
Invalid label
BadCodepoint(CodepointInfo)
Detected a disallowed Unicode code pint in the label.
CodepointInfo contains information about the code point.
Unexpected(UnexpectedError)
Error used to deal with any unexpected condition not directly covered by any other category.