Trait precis_core::profile::PrecisFastInvocation [−][src]
pub trait PrecisFastInvocation {
fn prepare(s: &str) -> Result<Cow<'_, str>, Error>;
fn enforce(s: &str) -> Result<Cow<'_, str>, Error>;
fn compare(s1: &str, s2: &str) -> Result<bool, Error>;
}Expand description
Fast invokation trait that allows profiles to be used without providing a specific instance. This is usually achieved by using a static instance allocated with lazy_static