Struct precis_core::stringclasses::FreeformClass [−][src]
pub struct FreeformClass {}Expand description
Concrete class representing PRECIS FreeformClass from RFC 8264.
Example
use precis_core::{DerivedPropertyValue,FreeformClass,StringClass};
let ff = FreeformClass {};
// character 𐍁 is OtherLetterDigits (R)
assert_eq!(ff.get_value_from_char('𐍁'), DerivedPropertyValue::SpecClassPval);
// Character S is ASCII7 (K)
assert_eq!(ff.get_value_from_char('S'), DerivedPropertyValue::PValid);
// Character 0x1170 is OldHangulJamo (I)
assert_eq!(ff.get_value_from_codepoint(0x1170), DerivedPropertyValue::Disallowed);Trait Implementations
Callback invoked when the unicode code point belongs to OtherLetterDigits Read more
Callback invoked when the unicode code point belongs to Punctuation Read more
Gets the derived property value according to the algorithm defined in ``get_derived_property_value` Read more
Gets the derived property value according to the algorithm defined in ``get_derived_property_value` Read more