Trait precis_core::stringclasses::SpecificDerivedPropertyValue [−][src]
pub trait SpecificDerivedPropertyValue {
fn on_spaces(&self) -> DerivedPropertyValue;
fn on_symbols(&self) -> DerivedPropertyValue;
fn on_punctuation(&self) -> DerivedPropertyValue;
fn on_has_compat(&self) -> DerivedPropertyValue;
fn on_other_letter_digits(&self) -> DerivedPropertyValue;
}Expand description
Interface for specific classes to deal with specific unicode
code groups defined in RFC 8264.
Next callbacks will be invoked to calculate the derived property
value in the order defined in get_derived_property_value
Required methods
fn on_spaces(&self) -> DerivedPropertyValue
fn on_spaces(&self) -> DerivedPropertyValue
Callback invoked when the unicode code point belongs to Spaces
fn on_symbols(&self) -> DerivedPropertyValue
fn on_symbols(&self) -> DerivedPropertyValue
Callback invoked when the unicode code point belongs to Symbols
fn on_punctuation(&self) -> DerivedPropertyValue
fn on_punctuation(&self) -> DerivedPropertyValue
Callback invoked when the unicode code point belongs to Punctuation
fn on_has_compat(&self) -> DerivedPropertyValue
fn on_has_compat(&self) -> DerivedPropertyValue
Callback invoked when the unicode code point belongs to HasCompat
fn on_other_letter_digits(&self) -> DerivedPropertyValue
fn on_other_letter_digits(&self) -> DerivedPropertyValue
Callback invoked when the unicode code point belongs to OtherLetterDigits