Struct precis_core::CodepointInfo
source · [−]pub struct CodepointInfo {
pub cp: u32,
pub position: usize,
pub property: DerivedPropertyValue,
}Expand description
Error that contains information regarding the wrong Unicode code point
Fields
cp: u32Unicode code point
position: usizeThe position of the Unicode code point in the label
property: DerivedPropertyValueThe derived property value
Implementations
sourceimpl CodepointInfo
impl CodepointInfo
sourcepub fn new(cp: u32, position: usize, property: DerivedPropertyValue) -> Self
pub fn new(cp: u32, position: usize, property: DerivedPropertyValue) -> Self
Creates a new CodepointInfo struct